==> interflow-1.0.2.tar.gz: interflow-1.0.2/docs/source/conf.py <==
# Configuration file for the Sphinx documentation builder.
#


# -- Path setup --------------------------------------------------------------

import os
import sys
sys.path.insert(0, os.path.abspath(r'C:\Users\mong275\Local Files\Repos\interflow'))


# -- Project information -----------------------------------------------------

project = 'interflow'
copyright = '2022, Battelle Memorial Institute'
author = 'Kendall Mongird'


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ['sphinxemoji.sphinxemoji',
              'sphinx.ext.autodoc']

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'alabaster'

html_theme_options = {'description': 'a multi-sectoral resource interdependency flow builder'}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

==> interflow-1.0.3.tar.gz: interflow-1.0.3/docs/source/conf.py <==
# Configuration file for the Sphinx documentation builder.
#


# -- Path setup --------------------------------------------------------------

import os
import sys
sys.path.insert(0, os.path.abspath('../../'))


# -- Project information -----------------------------------------------------

project = 'interflow'
copyright = '2022, Battelle Memorial Institute'
author = 'Kendall Mongird'


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ['sphinxemoji.sphinxemoji',
              'sphinx.ext.autodoc']

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'alabaster'

html_theme_options = {'description': 'a multi-sectoral resource interdependency flow builder'}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']
